@@ -804,8 +804,7 @@ class Client:
     def __build_urls(self) -> str:
         '''Generate URLs based on region/shard'''
         base_url = base_endpoint.format(shard=self.shard)
-        base_url_glz = base_endpoint_glz.format(
-            shard=self.shard, region=self.region)
+        base_url_glz = base_endpoint_glz.format(shard=self.shard, region=self.region)
         base_url_shared = base_endpoint_shared.format(region=self.shard)
         return base_url, base_url_glz, base_url_shared
 
